@@ -8,13 +8,7 @@ from abc import ABCMeta
 import cruisecontrolclient.client.CCParameter as CCParameter
 
 # To allow us to make more-precise type hints
-from typing import Callable, ClassVar, Dict, List, Tuple, Union  # noqa
-
-# To help us generate the right parameter string from a dict of parameters
-from urllib.parse import urlencode
-
-# To be able to deprecate methods
-import warnings
+from typing import Callable, ClassVar, Dict, List, Tuple, Union
 
 
 class AbstractEndpoint(metaclass=ABCMeta):
@@ -160,32 +154,6 @@ class AbstractEndpoint(metaclass=ABCMeta):
 
         return combined_parameter_to_value
 
-    def compose_endpoint(self) -> str:
-        """
-        Returns a valid URL suffix of this endpoint and any parameters
-        that have been defined for it.
-
-        Note that the ordering of the parameters is not guaranteed.
-
-        :return: A string like:
-            'rebalance?dryrun=false&allow_capacity_estimation=false&concurrent_partition_movements_per_broker=5'
-            'state'
-            'stop_proposal_execution'
-        """
-        warnings.warn("This method is deprecated as of 0.2.0, as it needlessly recreates requests functionality. "
-                      "It may be removed entirely in future versions. "
-                      "Please use get_composed_params instead.",
-                      DeprecationWarning,
-                      stacklevel=2)
-        combined_parameter_to_value = self.get_composed_params()
-
-        # If we have any mappings, urlencode them and return the full string
-        if combined_parameter_to_value:
-            return f"{self.name}?{urlencode(combined_parameter_to_value)}"
-        # Otherwise, just return this Endpoint's name
-        else:
-            return self.name
-
 
 class AddBrokerEndpoint(AbstractEndpoint):
     name = "add_broker"
@@ -203,6 +171,7 @@ class AddBrokerEndpoint(AbstractEndpoint):
         CCParameter.ExcludedTopicsParameter,
         CCParameter.GoalsParameter,
         CCParameter.JSONParameter,
+        CCParameter.ReasonParameter,
         CCParameter.ReviewIDParameter,
         CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.SkipHardGoalCheckParameter,
@@ -229,6 +198,8 @@ class AdminEndpoint(AbstractEndpoint):
         CCParameter.ConcurrentLeaderMovementsParameter,
         CCParameter.ConcurrentPartitionMovementsPerBrokerParameter,
         CCParameter.DisableSelfHealingForParameter,
+        CCParameter.DropRecentlyDemotedBrokersParameter,
+        CCParameter.DropRecentlyRemovedBrokersParameter,
         CCParameter.EnableSelfHealingForParameter,
         CCParameter.JSONParameter,
         CCParameter.ReviewIDParameter,
@@ -269,6 +240,7 @@ class DemoteBrokerEndpoint(AbstractEndpoint):
         CCParameter.ExcludeFollowerDemotionParameter,
         CCParameter.ExcludeRecentlyDemotedBrokersParameter,
         CCParameter.JSONParameter,
+        CCParameter.ReasonParameter,
         CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.ReviewIDParameter,
         CCParameter.SkipURPDemotionParameter,
@@ -291,7 +263,21 @@ class FixOfflineReplicasEndpoint(AbstractEndpoint):
     http_method = "POST"
     can_execute_proposal = True
     available_Parameters = (
+        CCParameter.AllowCapacityEstimationParameter,
+        CCParameter.ConcurrentLeaderMovementsParameter,
+        CCParameter.ConcurrentPartitionMovementsPerBrokerParameter,
+        CCParameter.DryRunParameter,
+        CCParameter.ExcludeRecentlyDemotedBrokersParameter,
+        CCParameter.ExcludeRecentlyRemovedBrokersParameter,
+        CCParameter.ExcludedTopicsParameter,
+        CCParameter.GoalsParameter,
+        CCParameter.JSONParameter,
+        CCParameter.ReasonParameter,
+        CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.ReviewIDParameter,
+        CCParameter.SkipHardGoalCheckParameter,
+        CCParameter.UseReadyDefaultGoalsParameter,
+        CCParameter.VerboseParameter
     )
     argparse_properties = {
         'args': (name,),
@@ -412,6 +398,7 @@ class RebalanceEndpoint(AbstractEndpoint):
         CCParameter.GoalsParameter,
         CCParameter.IgnoreProposalCacheParameter,
         CCParameter.JSONParameter,
+        CCParameter.ReasonParameter,
         CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.ReviewIDParameter,
         CCParameter.SkipHardGoalCheckParameter,
@@ -444,6 +431,7 @@ class RemoveBrokerEndpoint(AbstractEndpoint):
         CCParameter.ExcludedTopicsParameter,
         CCParameter.GoalsParameter,
         CCParameter.JSONParameter,
+        CCParameter.ReasonParameter,
         CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.ReviewIDParameter,
         CCParameter.SkipHardGoalCheckParameter,
@@ -561,11 +549,12 @@ class TopicConfigurationEndpoint(AbstractEndpoint):
         CCParameter.ExcludeRecentlyRemovedBrokersParameter,
         CCParameter.GoalsParameter,
         CCParameter.JSONParameter,
-        CCParameter.SkipHardGoalCheckParameter,
-        CCParameter.SkipRackAwarenessCheckParameter,
+        CCParameter.ReasonParameter,
         CCParameter.ReplicaMovementStrategiesParameter,
         CCParameter.ReplicationFactorParameter,
         CCParameter.ReviewIDParameter,
+        CCParameter.SkipHardGoalCheckParameter,
+        CCParameter.SkipRackAwarenessCheckParameter,
         CCParameter.TopicParameter,
         CCParameter.VerboseParameter
     )
